# PyRoll Wusatowski Spreading

Plugin for PyRoll providing the Wusatowski spreading model for high and low strains.

For the docs, see [here](docs/docs.pdf).

This project is licensed under the [BSD-3-Clause license](LICENSE).

The package is available via [PyPi](https://pypi.org/project/pyroll-wusatowski-spreading/) and can be installed with
    
    pip install pyroll-wusatowski-spreading